@@ -97,12 +97,23 @@ has number_of_args_constraints => (
         $tc->can('is_strictly_a_type_of') &&
         $tc->is_strictly_a_type_of('Tuple'))
       {
-        my @parameters = @{ $tc->parameters||[]};
-        if( defined($parameters[-1]) and exists($parameters[-1]->{slurpy})) {
-          return undef;
-        } else {
-          return my $total_params = scalar(@parameters);
+        my @parameters = @{ $tc->parameters||[] };
+        my $final = $parameters[-1];
+        if ( defined $final ) {
+          if ( blessed $final ) {
+            # modern form of slurpy
+            if ($final->can('is_strictly_a_type_of') && $final->is_strictly_a_type_of('Slurpy')) {
+              return undef;
+            }
+          }
+          else {
+            # old form of slurpy
+            if (ref $final eq 'HASH' && $final->{slurpy}) {
+              return undef;
+            }
+          }
         }
+        return scalar @parameters;
       } elsif($tc->is_a_type_of('Ref')) {
         return undef;
       } else {
@@ -460,6 +471,11 @@ sub compare {
     return $a1->comparable_arg_number <=> $a2->comparable_arg_number;
 }
 
+sub equals {
+  my ($self, $target) = @_;
+  return $self->private_path eq $target->private_path ? $self : 0;
+}
+
 sub scheme {
   return exists $_[0]->attributes->{Scheme} ? $_[0]->attributes->{Scheme}[0] : undef;
 }
@@ -536,6 +552,12 @@ Tries to find a type constraint if you have on on a type constrained method.
 Compares 2 actions based on the value of the C<Args> attribute, with no C<Args>
 having the highest precedence.
 
+=head2 equals
+
+    if( $action->equal($other_action) ) { ... }
+
+Returns true if the two actions are equal.
+
 =head2 namespace
 
 Returns the private namespace this action lives in.
